@@ -279,7 +279,7 @@ expect_col_exists <- function(object,
     interrogate() %>%
     .$validation_set
   
-  x <- vs$notify %>% all()
+  x <- vs$notify
   
   threshold_type <- get_threshold_type(threshold = threshold)
   
@@ -289,6 +289,25 @@ expect_col_exists <- function(object,
     failed_amount <- vs$n_failed
   }
   
+  # If several validations were performed serially (due to supplying
+  # multiple columns)
+  if (length(x) > 1 && any(x)) {
+    
+    # Get the index (step) of the first failure instance
+    fail_idx <- which(x)[1]
+    
+    # Get the correct, single `failed_amount` for the first
+    # failure instance
+    failed_amount <- failed_amount[fail_idx]
+    
+    # Redefine `x` as a single TRUE value
+    x <- TRUE
+    
+  } else {
+    x <- any(x)
+    fail_idx <- 1
+  }
+  
   if (inherits(vs$capture_stack[[1]]$warning, "simpleWarning")) {
     warning(conditionMessage(vs$capture_stack[[1]]$warning))
   }
@@ -298,7 +317,7 @@ expect_col_exists <- function(object,
   
   act <- testthat::quasi_label(enquo(x), arg = "object")
   
-  column_text <- prep_column_text(vs$column[[1]])
+  column_text <- prep_column_text(vs$column[[fail_idx]])
   
   testthat::expect(
     ok = identical(!as.vector(act$val), TRUE),
