@@ -167,7 +167,7 @@
 #' 
 #' @family validation functions
 #' @section Function ID:
-#' 2-27
+#' 2-26
 #' 
 #' @name col_is_date
 NULL
@@ -273,7 +273,7 @@ expect_col_is_date <- function(object,
     interrogate() %>%
     .$validation_set
   
-  x <- vs$notify %>% all()
+  x <- vs$notify
   
   threshold_type <- get_threshold_type(threshold = threshold)
   
@@ -283,6 +283,25 @@ expect_col_is_date <- function(object,
     failed_amount <- vs$n_failed
   }
   
+  # If several validations were performed serially (due to supplying
+  # multiple columns)
+  if (length(x) > 1 && any(x)) {
+    
+    # Get the index (step) of the first failure instance
+    fail_idx <- which(x)[1]
+    
+    # Get the correct, single `failed_amount` for the first
+    # failure instance
+    failed_amount <- failed_amount[fail_idx]
+    
+    # Redefine `x` as a single TRUE value
+    x <- TRUE
+    
+  } else {
+    x <- any(x)
+    fail_idx <- 1
+  }
+  
   if (inherits(vs$capture_stack[[1]]$warning, "simpleWarning")) {
     warning(conditionMessage(vs$capture_stack[[1]]$warning))
   }
@@ -292,7 +311,7 @@ expect_col_is_date <- function(object,
   
   act <- testthat::quasi_label(enquo(x), arg = "object")
   
-  column_text <- prep_column_text(vs$column[[1]])
+  column_text <- prep_column_text(vs$column[[fail_idx]])
   col_type <- "Date"
   
   testthat::expect(
