@@ -408,7 +408,7 @@ info_columns <- function(x,
                          columns,
                          ...,
                          .add = TRUE) {
-
+  
   # Capture the `columns` expression
   columns <- rlang::enquo(columns)
   
@@ -424,7 +424,19 @@ info_columns <- function(x,
   # Resolve the columns based on the expression
   columns <- resolve_columns(x = x, var_expr = columns, preconditions = NULL)
   
+  if (length(columns) == 1 && is.na(columns)) {
+   
+    warning(
+      "No columns were matched with the expression used, so, no ",
+      "info was added.",
+      call. = FALSE
+    )
+    
+    return(metadata)
+  }
+  
   for (column in columns) {
+    
     for (i in seq_along(metadata_items)) {
       
       item_name <- names(metadata_items[i])
@@ -462,6 +474,152 @@ info_columns <- function(x,
   metadata
 }
 
+
+#' Add column information from another data table
+#' 
+#' @description
+#' The `info_columns_from_tbl()` function is a wrapper around the
+#' [info_columns()] function and is useful if you wish to apply *info text* to
+#' columns where that information already exists in a data frame (or in some
+#' form that can readily be coaxed into a data frame). The form of the input
+#' `tbl` (the one that contains column metadata) has a few basic requirements:
+#' 
+#' - the data frame must have two columns
+#' - both columns must be of class `character`
+#' - the first column should contain column names and the second should contain
+#' the *info text*
+#' 
+#' Each column that matches across tables (i.e., the `tbl` and the target table
+#' of the informant) will have a new entry for the `"info"` property. Empty or
+#' missing info text will be pruned from `tbl`.
+#' 
+#' @param x An informant object of class `ptblank_informant`.
+#' @param tbl The two-column data frame which contains metadata about the target
+#'   table in the informant object. 
+#' @param .add Should new text be added to existing text? This is `TRUE` by
+#'   default; setting to `FALSE` replaces any existing text for the `"info"`
+#'   property.
+#' 
+#' @return A `ptblank_informant` object.
+#' 
+#' @examples 
+#' # Create a pointblank `informant`
+#' # object with `create_informant()`;
+#' # we specify a `read_fn` with the
+#' # `~` followed by a statement that
+#' # gets the `game_revenue` dataset
+#' informant <- 
+#'   create_informant(
+#'     read_fn = ~ game_revenue,
+#'     tbl_name = "game_revenue",
+#'     label = "An example."
+#'   )
+#' 
+#' # We can add *info text* to describe
+#' # the columns in the table by using
+#' # information in another table; the
+#' # `info_columns_from_tbl()` takes a
+#' # table object where the first column
+#' # has the column names and the second
+#' # contains the *info text* (the
+#' # `game_revenue_info` dataset contains
+#' # metadata for `game_revenue`)
+#' informant <-
+#'   informant %>%
+#'   info_columns_from_tbl(
+#'     tbl = game_revenue_info
+#'   )
+#' 
+#' # We can continue to add more *info
+#' # text* since the process is additive;
+#' # the `info_columns_from_tbl()`
+#' # function populates the `info`
+#' # subsection
+#' informant <-
+#'   informant %>%
+#'   info_columns(
+#'     columns = "item_revenue",
+#'     info = "Revenue reported in USD."
+#'   ) %>%
+#'   info_columns(
+#'     columns = "acquisition",
+#'     `top list` = "{top5_aq}"
+#'   ) %>%
+#'   info_snippet(
+#'     snippet_name = "top5_aq",
+#'     fn = snip_list(column = "acquisition")
+#'   ) %>%
+#'   incorporate()
+#' 
+#' @family Information Functions
+#' @section Function ID:
+#' 3-3
+#' 
+#' @seealso The [info_columns()] function, which allows for manual entry of
+#'   *info text*.
+#'
+#' @export
+info_columns_from_tbl <- function(x,
+                                  tbl,
+                                  .add = TRUE) {
+
+  # Ensure that `tbl` passes a validation check 
+  tbl <- check_info_columns_tbl(tbl = tbl)
+  
+  # Call `info_columns()` for every row in `tbl`
+  for (i in seq_along(tbl$column)) {
+
+    x <- 
+      info_columns(
+        x = x,
+        columns = tbl$column[i],
+        info = tbl$info[i],
+        .add = .add
+      )
+  }  
+  
+  x
+}
+
+check_info_columns_tbl <- function(tbl) {
+  
+  if (
+    !inherits(tbl, "data.frame") &&
+    !ncol(tbl) == 2 &&
+    !inherits(dplyr::pull(tbl, 1), "character") &&
+    !inherits(dplyr::pull(tbl, 2), "character")
+  ) {
+    
+    stop(
+      "The input `tbl` must fulfill the following conditions:\n",
+      "* inherits from data.frame\n",
+      "* has two columns\n",
+      "* both columns must be of type `character`",
+      call. = FALSE
+    )
+  }
+  
+  # Standardize the column names in `tbl`
+  colnames(tbl) <- c("column", "info")
+  
+  # Filter out any missing or NA values in the `info` column
+  tbl <- 
+    tbl %>%
+    dplyr::filter(!is.na(info) & !grepl("^\\s*$", info))
+  
+  colnames_in_tbl <- dplyr::pull(tbl, column)
+  
+  if (anyDuplicated(colnames_in_tbl) != 0) {
+    
+    stop(
+      "The input `tbl` contains duplicate column names in the first column.",
+      call. = FALSE
+    )
+  }
+  
+  tbl
+}
+
 #' Add information that focuses on some key aspect of the data table
 #' 
 #' @description 
@@ -605,7 +763,8 @@ info_columns <- function(x,
 #'     section_name = "Notes",
 #'     creation = "Dataset generated on (2020-01-15).",
 #'     usage = "`small_table %>% dplyr::glimpse()`"
-#'   )
+#'   ) %>%
+#'   incorporate()
 #' 
 #' # Upon printing the `informant` object, we see
 #' # the addition of the 'Notes' section and its
@@ -637,7 +796,7 @@ info_columns <- function(x,
 #'
 #' @family Information Functions
 #' @section Function ID:
-#' 3-3
+#' 3-4
 #'
 #' @export
 info_section <- function(x,
@@ -664,6 +823,7 @@ info_section <- function(x,
     item_value <- metadata_items[[i]]
     
     if (!(item_name %in% names(metadata_section))) {
+      
       # Case where `item_name` doesn't exist for the section
       metadata_section <- 
         c(
@@ -671,6 +831,7 @@ info_section <- function(x,
           metadata_items[i]
         )
     } else {
+      
       # Case where `item_name` exists for the section
       metadata_section[[item_name]] <- item_value
     }
@@ -833,7 +994,7 @@ info_section <- function(x,
 #' 
 #' @family Information Functions
 #' @section Function ID:
-#' 3-4
+#' 3-5
 #' 
 #' @export
 info_snippet <- function(x,
@@ -938,7 +1099,7 @@ info_snippet <- function(x,
 #' 
 #' @family Information Functions
 #' @section Function ID:
-#' 3-5
+#' 3-6
 #' 
 #' @export
 snip_list <- function(column,
@@ -1147,7 +1308,7 @@ snip_list <- function(column,
 #' 
 #' @family Information Functions
 #' @section Function ID:
-#' 3-6
+#' 3-7
 #' 
 #' @export
 snip_stats <- function(column,
@@ -1208,7 +1369,7 @@ snip_stats <- function(column,
 #' 
 #' @family Information Functions
 #' @section Function ID:
-#' 3-7
+#' 3-8
 #' 
 #' @export
 snip_lowest <- function(column) {
@@ -1266,7 +1427,7 @@ snip_lowest <- function(column) {
 #' 
 #' @family Information Functions
 #' @section Function ID:
-#' 3-8
+#' 3-9
 #' 
 #' @export
 snip_highest <- function(column) {
