@@ -187,11 +187,52 @@ create_autobrief <- function(agent,
                              column = NULL,
                              values = NULL) {
 
+  if (assertion_type == "serially") {
+
+    # Develop a brief that explains how many tests are included
+    # and what the final expectation is (if included)
+    
+    # Get number of test steps
+    test_step_count <- values$total_test_calls
+    
+    # Get assertion type for final validation, if present
+    has_final_validation <- values$has_final_validation
+
+    if (has_final_validation) {
+      assertion_type <- values$final_validation_type
+    } else {
+      autobrief <- ""
+    }
+    
+    preconditions <- values$final_validation_preconditions
+    column <- values$final_validation_column
+    values <- values$final_validation_values
+    
+    finalize_serially_brief <- TRUE
+    
+  } else {
+    
+    finalize_serially_brief <- FALSE
+  }
+  
   lang <- agent$lang
-  precondition_text <- prep_precondition_text(preconditions, lang = lang)
-  column_computed_text <- prep_column_computed_text(agent, column, lang = lang)
-  values_text <- prep_values_text(values, lang = lang)
-  column_text <- prep_column_text(column)
+  
+  precondition_text <- 
+    prep_precondition_text(
+      preconditions = preconditions,
+      lang = lang
+    )
+  
+  column_computed_text <- 
+    prep_column_computed_text(
+      agent = agent,
+      column = column,
+      lang = lang
+    )
+  
+  column_text <- prep_column_text(column = column)
+  
+  values_text <- prep_values_text(values = values, lang = lang)
   
   if (assertion_type %in%
       c("col_vals_gt", "col_vals_gte",
@@ -362,6 +403,13 @@ create_autobrief <- function(agent,
     autobrief <- finalize_autobrief(expectation_text, precondition_text)
   }
   
+  if (assertion_type == "rows_complete") {
+    
+    expectation_text <- 
+      prep_row_complete_expectation_text(column_text, lang = lang)
+    autobrief <- finalize_autobrief(expectation_text, precondition_text)
+  }
+  
   if (assertion_type == "col_schema_match") {
     
     expectation_text <- prep_col_schema_match_expectation_text(lang = lang)
@@ -376,6 +424,30 @@ create_autobrief <- function(agent,
     autobrief <- finalize_autobrief(expectation_text, precondition_text)
   }
   
+  if (assertion_type == "specially") {
+    
+    expectation_text <- prep_specially_expectation_text(lang = lang)
+    autobrief <- finalize_autobrief(expectation_text, precondition_text) 
+  }
+  
+  if (finalize_serially_brief) {
+    
+    serially_test_text <-
+      get_serially_test_text(
+        test_step_count = test_step_count,
+        lang = lang
+      )
+    
+    if (test_step_count == 1) {
+      
+      autobrief <- serially_test_text
+    
+    } else {
+      
+      autobrief <- paste(serially_test_text, autobrief)
+    }
+  }
+  
   autobrief
 }
 
@@ -622,6 +694,26 @@ prep_conjointly_expectation_text <- function(values_text,
   glue::glue(get_lsv("autobriefs/conjointly_expectation_text")[[lang]])
 }
 
+prep_specially_expectation_text <- function(lang) {
+  
+  glue::glue(get_lsv("autobriefs/specially_expectation_text")[[lang]])
+}
+
+get_serially_test_text <- function(test_step_count,
+                                   lang) {
+  
+  if (test_step_count > 1) {
+    
+    as.character(
+      glue::glue(get_lsv("autobriefs/serially_expectation_tests_text")[[lang]])
+    )
+    
+  } else {
+    
+    get_lsv("autobriefs/serially_expectation_test_text")[[lang]]
+  }
+}
+
 prep_col_exists_expectation_text <- function(column_text,
                                              lang) {
   
@@ -649,6 +741,20 @@ prep_row_distinct_expectation_text <- function(column_text,
   }
 }
 
+prep_row_complete_expectation_text <- function(column_text,
+                                               lang) {
+  
+  if (column_text == "``") {
+    glue::glue(
+      get_lsv("autobriefs/all_row_complete_expectation_text")[[lang]]
+    )
+  } else {
+    glue::glue(
+      get_lsv("autobriefs/across_row_complete_expectation_text")[[lang]]
+    )
+  }
+}
+
 prep_col_schema_match_expectation_text <- function(lang) {
   
   glue::glue(get_lsv("autobriefs/col_schema_match_expectation_text")[[lang]])
@@ -698,6 +804,7 @@ failure_message_gluestring <- function(fn_name,
       "expect_col_is_date" =,
       "expect_col_is_factor" = get_lsv("autobriefs/col_is_failure_text")[[lang]],
       "expect_rows_distinct" = get_lsv("autobriefs/all_row_distinct_failure_text")[[lang]],
+      "expect_rows_complete" = get_lsv("autobriefs/all_row_complete_failure_text")[[lang]],
       "expect_col_schema_match" = get_lsv("autobriefs/col_schema_match_failure_text")[[lang]]
     )
   
