@@ -94,8 +94,10 @@ utils::globalVariables(
     "Frequency",
     "head.ref",
     "i",
+    "info",
     "item",
     "i_o",
+    "interrogation_notes",
     "label",
     "::labels::",
     "merge_commit_sha",
@@ -111,6 +113,7 @@ utils::globalVariables(
     "number",
     ".panel_x",
     ".panel_y",
+    ".param.",
     "pb_is_good_",
     "pb_is_good_1_",
     "pb_is_good_2_",
